use strict;
use warnings;
package Email::ARF 0.012;
# ABSTRACT: abuse report format (placeholder module)

#pod =head1 REFERENCES
#pod
#pod You probably wanted to be looking at L<Email::ARF::Report>.
#pod
#pod =cut

warn "This module does nothing." unless $ENV{HARNESS_ACTIVE};

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Email::ARF - abuse report format (placeholder module)

=head1 VERSION

version 0.012

=head1 PERL VERSION

This library should run on perls released even a long time ago.  It should
work on any version of perl released in the last five years.

Although it may work on older versions of perl, no guarantee is made that the
minimum required version will not be increased.  The version may be increased
for any reason, and there is no promise that patches will be accepted to
lower the minimum required perl.

=head1 REFERENCES

You probably wanted to be looking at L<Email::ARF::Report>.

=head1 AUTHOR

Ricardo Signes <cpan@semiotic.systems>

=head1 CONTRIBUTORS

=for stopwords Chase Venters Michael Stevens Ricardo Signes

=over 4

=item *

Chase Venters <chase.venters@chaseventers.com>

=item *

Michael Stevens <mstevens@etla.org>

=item *

Ricardo Signes <rjbs@cpan.org>

=item *

Ricardo Signes <rjbs@semiotic.systems>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023 by Ricardo Signes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
